@@ -4,7 +4,7 @@ use warnings FATAL => 'all';
 
 package namespace::local;
 
-our $VERSION = '0.07_08';
+our $VERSION = '0.08_01';
 
 =head1 NAME
 
@@ -13,7 +13,34 @@ namespace::local - Confine imports or functions to a given scope
 =head1 SYNOPSIS
 
 This module allows to confine imports or private functions
-to a given scope. The following modes of operation exist:
+to a given scope.
+
+    package My::Module;
+
+    sub normal_method {
+        # frobnicate; # nope!
+    };
+
+    sub method_with_sugar {
+        use namespace::local;
+        use Crazy::Prototyped::DSL qw(do_this do_that frobnicate);
+
+        do_this;
+        do_that;
+        frobnicate;
+    };
+
+    sub another_method {
+        # frobnicate; # nope!
+    };
+
+The calling module's symbol table is saved at the C<use> line
+and restored upon leaving the block.
+
+The subsequent imports will do their job within the block,
+but will not be available as methods at runtime.
+
+=head1 MODES OF OPERATION
 
 =head2 -around
 
@@ -74,6 +101,21 @@ This emulates L<namespace::clean>, by which this module is clearly inspired.
 
     # now define public functions here
 
+=head2 no namespace::local
+
+Use C<no namespace::local> (C<unimport>) to force end of scope for the latest
+L<namespace::local> instance in action:
+
+    package My::Module;
+
+    use namespace::local;
+    sub private { ... };
+    no namespace::local;
+
+    # private not available here, even though the scope didn't end!
+
+No options are currently supported.
+
 =head1 OPTIONS
 
 Extra options may be passed to namespace::local:
@@ -165,9 +207,6 @@ Due to order of callback execution in L<B::Hooks::EndOfScope>,
 other modules in C<namespace::> namespace may interact poorly
 with L<namespace::local>.
 
-However, at least C<-above> and C<-below> switches
-work as expected if used simultaneously.
-
 Up to v.0.07, C<-around> used to be the default mode instead of C<-below>.
 C<-around> is much more restrictive, in particular, it prevents functions
 defined below the block from propagating above the block.
@@ -177,6 +216,7 @@ No perfect solution has yet been found.
 
 =cut
 
+use Carp;
 use B::Hooks::EndOfScope 'on_scope_end';
 
 my @stack;
@@ -195,13 +235,28 @@ sub import {
     $command->prepare;
 
     on_scope_end {
-        local $Carp::Internal{'B::Hooks::EndOfScope::XS'} = 1;
-        local $Carp::Internal{'B::Hooks::EndOfScope'} = 1;
-        pop @stack;
-        $command->execute;
+        if (!$command->is_done) {
+            pop @stack; # make sure push == pop
+            local $Carp::Internal{'B::Hooks::EndOfScope::XS'} = 1;
+            local $Carp::Internal{'B::Hooks::EndOfScope'} = 1;
+            $command->execute;
+        };
     };
 };
 
+sub unimport {
+    my $class = shift;
+
+    croak "No options supported for 'no namespace::local'"
+        if @_;
+
+    croak "'no namespace::local' called but namespace::local isn't active"
+        unless @stack;
+
+    my $command = pop @stack;
+    $command->execute;
+};
+
 =head1 ENVIRONMENT
 
 Set C<PERL_NAMESPACE_LOCAL=debug> to see some debugging information
@@ -233,7 +288,7 @@ are called upon import and leaving scope, respectively.
 
 sub new {
     my $unused = shift;
-    namespace::local::_command->new(@_);
+    namespace::local::_command->new(caller => [caller 0], @_);
 };
 
 package
@@ -293,6 +348,10 @@ sub set_next {
     $self->{next} = $next;
 };
 
+sub is_done {
+    return $_[0]->{done};
+};
+
 sub DESTROY {
     my $self = shift;
     carp "probably a bug in namespace::local: callback set at $self->{origin} but never executed"
